# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'pyinstaller_tool.ui'
#
# Created by: PyQt5 UI code generator 5.15.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_pyinstaller_tool(object):
    def setupUi(self, pyinstaller_tool):
        pyinstaller_tool.setObjectName("pyinstaller_tool")
        pyinstaller_tool.setWindowModality(QtCore.Qt.WindowModal)
        pyinstaller_tool.resize(860, 722)
        font = QtGui.QFont()
        font.setFamily("Microsoft YaHei UI")
        pyinstaller_tool.setFont(font)
        self.centralwidget = QtWidgets.QWidget(pyinstaller_tool)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_18 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_18.setContentsMargins(8, 8, 8, 8)
        self.verticalLayout_18.setObjectName("verticalLayout_18")
        self.splitter = QtWidgets.QSplitter(self.centralwidget)
        self.splitter.setOrientation(QtCore.Qt.Horizontal)
        self.splitter.setHandleWidth(6)
        self.splitter.setObjectName("splitter")
        self.tabWidget = QtWidgets.QTabWidget(self.splitter)
        self.tabWidget.setObjectName("tabWidget")
        self.tab_project_files = QtWidgets.QWidget()
        self.tab_project_files.setObjectName("tab_project_files")
        self.verticalLayout_29 = QtWidgets.QVBoxLayout(self.tab_project_files)
        self.verticalLayout_29.setObjectName("verticalLayout_29")
        self.verticalLayout_28 = QtWidgets.QVBoxLayout()
        self.verticalLayout_28.setObjectName("verticalLayout_28")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setSpacing(2)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.label = QtWidgets.QLabel(self.tab_project_files)
        self.label.setObjectName("label")
        self.verticalLayout_2.addWidget(self.label)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.le_program_entry_old = QtWidgets.QLineEdit(self.tab_project_files)
        self.le_program_entry_old.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_program_entry_old.setObjectName("le_program_entry_old")
        self.horizontalLayout_3.addWidget(self.le_program_entry_old)
        self.pb_select_program_entry = QtWidgets.QPushButton(self.tab_project_files)
        self.pb_select_program_entry.setObjectName("pb_select_program_entry")
        self.horizontalLayout_3.addWidget(self.pb_select_program_entry)
        self.horizontalLayout_3.setStretch(0, 1)
        self.verticalLayout_2.addLayout(self.horizontalLayout_3)
        self.verticalLayout_28.addLayout(self.verticalLayout_2)
        self.verticalLayout_19 = QtWidgets.QVBoxLayout()
        self.verticalLayout_19.setSpacing(2)
        self.verticalLayout_19.setObjectName("verticalLayout_19")
        self.label_13 = QtWidgets.QLabel(self.tab_project_files)
        self.label_13.setObjectName("label_13")
        self.verticalLayout_19.addWidget(self.label_13)
        self.le_output_name = QtWidgets.QLineEdit(self.tab_project_files)
        self.le_output_name.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_output_name.setObjectName("le_output_name")
        self.verticalLayout_19.addWidget(self.le_output_name)
        self.verticalLayout_28.addLayout(self.verticalLayout_19)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setSpacing(2)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_20 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_20.setObjectName("horizontalLayout_20")
        self.label_2 = QtWidgets.QLabel(self.tab_project_files)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_20.addWidget(self.label_2)
        self.pb_reset_root_level = QtWidgets.QPushButton(self.tab_project_files)
        self.pb_reset_root_level.setObjectName("pb_reset_root_level")
        self.horizontalLayout_20.addWidget(self.pb_reset_root_level)
        self.pb_up_level_root = QtWidgets.QPushButton(self.tab_project_files)
        self.pb_up_level_root.setObjectName("pb_up_level_root")
        self.horizontalLayout_20.addWidget(self.pb_up_level_root)
        self.horizontalLayout_20.setStretch(0, 1)
        self.verticalLayout.addLayout(self.horizontalLayout_20)
        self.le_project_root = QtWidgets.QLineEdit(self.tab_project_files)
        self.le_project_root.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_project_root.setReadOnly(True)
        self.le_project_root.setObjectName("le_project_root")
        self.verticalLayout.addWidget(self.le_project_root)
        self.verticalLayout_28.addLayout(self.verticalLayout)
        self.horizontalLayout_31 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_31.setObjectName("horizontalLayout_31")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setSpacing(2)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.horizontalLayout_19 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_19.setObjectName("horizontalLayout_19")
        self.label_26 = QtWidgets.QLabel(self.tab_project_files)
        self.label_26.setObjectName("label_26")
        self.horizontalLayout_19.addWidget(self.label_26)
        self.pb_clear_hidden_imports = QtWidgets.QPushButton(self.tab_project_files)
        self.pb_clear_hidden_imports.setObjectName("pb_clear_hidden_imports")
        self.horizontalLayout_19.addWidget(self.pb_clear_hidden_imports)
        self.horizontalLayout_19.setStretch(0, 1)
        self.verticalLayout_5.addLayout(self.horizontalLayout_19)
        self.pte_hidden_imports = QtWidgets.QPlainTextEdit(self.tab_project_files)
        self.pte_hidden_imports.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.pte_hidden_imports.setLineWrapMode(QtWidgets.QPlainTextEdit.NoWrap)
        self.pte_hidden_imports.setObjectName("pte_hidden_imports")
        self.verticalLayout_5.addWidget(self.pte_hidden_imports)
        self.horizontalLayout_31.addLayout(self.verticalLayout_5)
        self.verticalLayout_17 = QtWidgets.QVBoxLayout()
        self.verticalLayout_17.setSpacing(2)
        self.verticalLayout_17.setObjectName("verticalLayout_17")
        self.horizontalLayout_21 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_21.setObjectName("horizontalLayout_21")
        self.label_27 = QtWidgets.QLabel(self.tab_project_files)
        self.label_27.setObjectName("label_27")
        self.horizontalLayout_21.addWidget(self.label_27)
        self.pb_clear_exclude_module = QtWidgets.QPushButton(self.tab_project_files)
        self.pb_clear_exclude_module.setObjectName("pb_clear_exclude_module")
        self.horizontalLayout_21.addWidget(self.pb_clear_exclude_module)
        self.horizontalLayout_21.setStretch(0, 1)
        self.verticalLayout_17.addLayout(self.horizontalLayout_21)
        self.pte_exclude_modules = QtWidgets.QPlainTextEdit(self.tab_project_files)
        self.pte_exclude_modules.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.pte_exclude_modules.setLineWrapMode(QtWidgets.QPlainTextEdit.NoWrap)
        self.pte_exclude_modules.setObjectName("pte_exclude_modules")
        self.verticalLayout_17.addWidget(self.pte_exclude_modules)
        self.horizontalLayout_31.addLayout(self.verticalLayout_17)
        self.verticalLayout_28.addLayout(self.horizontalLayout_31)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setSpacing(2)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.label_3 = QtWidgets.QLabel(self.tab_project_files)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_5.addWidget(self.label_3)
        self.pb_clear_module_search_path = QtWidgets.QPushButton(self.tab_project_files)
        self.pb_clear_module_search_path.setObjectName("pb_clear_module_search_path")
        self.horizontalLayout_5.addWidget(self.pb_clear_module_search_path)
        self.pb_select_module_search_path = QtWidgets.QPushButton(self.tab_project_files)
        self.pb_select_module_search_path.setObjectName("pb_select_module_search_path")
        self.horizontalLayout_5.addWidget(self.pb_select_module_search_path)
        self.horizontalLayout_5.setStretch(0, 1)
        self.verticalLayout_3.addLayout(self.horizontalLayout_5)
        self.te_module_search_path_old = QtWidgets.QTextEdit(self.tab_project_files)
        self.te_module_search_path_old.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.te_module_search_path_old.setObjectName("te_module_search_path_old")
        self.verticalLayout_3.addWidget(self.te_module_search_path_old)
        self.verticalLayout_28.addLayout(self.verticalLayout_3)
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setSpacing(2)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.label_4 = QtWidgets.QLabel(self.tab_project_files)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_6.addWidget(self.label_4)
        self.pb_clear_other_data = QtWidgets.QPushButton(self.tab_project_files)
        self.pb_clear_other_data.setObjectName("pb_clear_other_data")
        self.horizontalLayout_6.addWidget(self.pb_clear_other_data)
        self.pb_select_other_data = QtWidgets.QPushButton(self.tab_project_files)
        self.pb_select_other_data.setObjectName("pb_select_other_data")
        self.horizontalLayout_6.addWidget(self.pb_select_other_data)
        self.horizontalLayout_6.setStretch(0, 1)
        self.verticalLayout_4.addLayout(self.horizontalLayout_6)
        self.te_other_data_old = QtWidgets.QTextEdit(self.tab_project_files)
        self.te_other_data_old.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.te_other_data_old.setObjectName("te_other_data_old")
        self.verticalLayout_4.addWidget(self.te_other_data_old)
        self.verticalLayout_28.addLayout(self.verticalLayout_4)
        self.verticalLayout_8 = QtWidgets.QVBoxLayout()
        self.verticalLayout_8.setSpacing(2)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.label_7 = QtWidgets.QLabel(self.tab_project_files)
        self.label_7.setObjectName("label_7")
        self.verticalLayout_8.addWidget(self.label_7)
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.le_file_icon_path_old = QtWidgets.QLineEdit(self.tab_project_files)
        self.le_file_icon_path_old.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_file_icon_path_old.setObjectName("le_file_icon_path_old")
        self.horizontalLayout_11.addWidget(self.le_file_icon_path_old)
        self.pb_select_file_icon = QtWidgets.QPushButton(self.tab_project_files)
        self.pb_select_file_icon.setObjectName("pb_select_file_icon")
        self.horizontalLayout_11.addWidget(self.pb_select_file_icon)
        self.horizontalLayout_11.setStretch(0, 1)
        self.verticalLayout_8.addLayout(self.horizontalLayout_11)
        self.verticalLayout_28.addLayout(self.verticalLayout_8)
        self.verticalLayout_29.addLayout(self.verticalLayout_28)
        self.tabWidget.addTab(self.tab_project_files, "")
        self.tab_build_control = QtWidgets.QWidget()
        self.tab_build_control.setObjectName("tab_build_control")
        self.verticalLayout_14 = QtWidgets.QVBoxLayout(self.tab_build_control)
        self.verticalLayout_14.setObjectName("verticalLayout_14")
        self.verticalLayout_12 = QtWidgets.QVBoxLayout()
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.rb_pack_to_one_dir = QtWidgets.QRadioButton(self.tab_build_control)
        self.rb_pack_to_one_dir.setObjectName("rb_pack_to_one_dir")
        self.horizontalLayout_9.addWidget(self.rb_pack_to_one_dir)
        self.rb_pack_to_one_file = QtWidgets.QRadioButton(self.tab_build_control)
        self.rb_pack_to_one_file.setObjectName("rb_pack_to_one_file")
        self.horizontalLayout_9.addWidget(self.rb_pack_to_one_file)
        self.verticalLayout_12.addLayout(self.horizontalLayout_9)
        self.cb_execute_with_console = QtWidgets.QCheckBox(self.tab_build_control)
        self.cb_execute_with_console.setObjectName("cb_execute_with_console")
        self.verticalLayout_12.addWidget(self.cb_execute_with_console)
        self.cb_without_confirm = QtWidgets.QCheckBox(self.tab_build_control)
        self.cb_without_confirm.setObjectName("cb_without_confirm")
        self.verticalLayout_12.addWidget(self.cb_without_confirm)
        self.cb_use_upx = QtWidgets.QCheckBox(self.tab_build_control)
        self.cb_use_upx.setObjectName("cb_use_upx")
        self.verticalLayout_12.addWidget(self.cb_use_upx)
        self.cb_clean_before_build = QtWidgets.QCheckBox(self.tab_build_control)
        self.cb_clean_before_build.setObjectName("cb_clean_before_build")
        self.verticalLayout_12.addWidget(self.cb_clean_before_build)
        self.cb_write_info_to_exec = QtWidgets.QCheckBox(self.tab_build_control)
        self.cb_write_info_to_exec.setObjectName("cb_write_info_to_exec")
        self.verticalLayout_12.addWidget(self.cb_write_info_to_exec)
        self.cb_uac_admin = QtWidgets.QCheckBox(self.tab_build_control)
        self.cb_uac_admin.setObjectName("cb_uac_admin")
        self.verticalLayout_12.addWidget(self.cb_uac_admin)
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.label_11 = QtWidgets.QLabel(self.tab_build_control)
        self.label_11.setObjectName("label_11")
        self.horizontalLayout_15.addWidget(self.label_11)
        self.le_bytecode_encryption_key = QtWidgets.QLineEdit(self.tab_build_control)
        self.le_bytecode_encryption_key.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_bytecode_encryption_key.setObjectName("le_bytecode_encryption_key")
        self.horizontalLayout_15.addWidget(self.le_bytecode_encryption_key)
        self.verticalLayout_12.addLayout(self.horizontalLayout_15)
        self.verticalLayout_9 = QtWidgets.QVBoxLayout()
        self.verticalLayout_9.setSpacing(2)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.label_8 = QtWidgets.QLabel(self.tab_build_control)
        self.label_8.setObjectName("label_8")
        self.verticalLayout_9.addWidget(self.label_8)
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.le_output_dir = QtWidgets.QLineEdit(self.tab_build_control)
        self.le_output_dir.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_output_dir.setObjectName("le_output_dir")
        self.horizontalLayout_12.addWidget(self.le_output_dir)
        self.pb_select_output_dir = QtWidgets.QPushButton(self.tab_build_control)
        self.pb_select_output_dir.setObjectName("pb_select_output_dir")
        self.horizontalLayout_12.addWidget(self.pb_select_output_dir)
        self.verticalLayout_9.addLayout(self.horizontalLayout_12)
        self.verticalLayout_12.addLayout(self.verticalLayout_9)
        self.verticalLayout_15 = QtWidgets.QVBoxLayout()
        self.verticalLayout_15.setSpacing(2)
        self.verticalLayout_15.setObjectName("verticalLayout_15")
        self.label_17 = QtWidgets.QLabel(self.tab_build_control)
        self.label_17.setObjectName("label_17")
        self.verticalLayout_15.addWidget(self.label_17)
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_16.setObjectName("horizontalLayout_16")
        self.le_spec_dir = QtWidgets.QLineEdit(self.tab_build_control)
        self.le_spec_dir.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_spec_dir.setObjectName("le_spec_dir")
        self.horizontalLayout_16.addWidget(self.le_spec_dir)
        self.pb_select_spec_dir = QtWidgets.QPushButton(self.tab_build_control)
        self.pb_select_spec_dir.setObjectName("pb_select_spec_dir")
        self.horizontalLayout_16.addWidget(self.pb_select_spec_dir)
        self.verticalLayout_15.addLayout(self.horizontalLayout_16)
        self.verticalLayout_12.addLayout(self.verticalLayout_15)
        self.verticalLayout_11 = QtWidgets.QVBoxLayout()
        self.verticalLayout_11.setSpacing(2)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.label_10 = QtWidgets.QLabel(self.tab_build_control)
        self.label_10.setObjectName("label_10")
        self.verticalLayout_11.addWidget(self.label_10)
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.le_temp_working_dir = QtWidgets.QLineEdit(self.tab_build_control)
        self.le_temp_working_dir.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_temp_working_dir.setObjectName("le_temp_working_dir")
        self.horizontalLayout_14.addWidget(self.le_temp_working_dir)
        self.pb_select_temp_working_dir = QtWidgets.QPushButton(self.tab_build_control)
        self.pb_select_temp_working_dir.setObjectName("pb_select_temp_working_dir")
        self.horizontalLayout_14.addWidget(self.pb_select_temp_working_dir)
        self.verticalLayout_11.addLayout(self.horizontalLayout_14)
        self.verticalLayout_12.addLayout(self.verticalLayout_11)
        self.verticalLayout_10 = QtWidgets.QVBoxLayout()
        self.verticalLayout_10.setSpacing(2)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.label_9 = QtWidgets.QLabel(self.tab_build_control)
        self.label_9.setObjectName("label_9")
        self.verticalLayout_10.addWidget(self.label_9)
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.le_upx_search_path = QtWidgets.QLineEdit(self.tab_build_control)
        self.le_upx_search_path.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_upx_search_path.setObjectName("le_upx_search_path")
        self.horizontalLayout_13.addWidget(self.le_upx_search_path)
        self.pb_select_upx_search_path = QtWidgets.QPushButton(self.tab_build_control)
        self.pb_select_upx_search_path.setObjectName("pb_select_upx_search_path")
        self.horizontalLayout_13.addWidget(self.pb_select_upx_search_path)
        self.verticalLayout_10.addLayout(self.horizontalLayout_13)
        self.verticalLayout_12.addLayout(self.verticalLayout_10)
        self.verticalLayout_13 = QtWidgets.QVBoxLayout()
        self.verticalLayout_13.setSpacing(2)
        self.verticalLayout_13.setObjectName("verticalLayout_13")
        self.label_14 = QtWidgets.QLabel(self.tab_build_control)
        self.label_14.setObjectName("label_14")
        self.verticalLayout_13.addWidget(self.label_14)
        self.te_upx_exclude_files = QtWidgets.QTextEdit(self.tab_build_control)
        self.te_upx_exclude_files.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.te_upx_exclude_files.setAcceptDrops(False)
        self.te_upx_exclude_files.setObjectName("te_upx_exclude_files")
        self.verticalLayout_13.addWidget(self.te_upx_exclude_files)
        self.verticalLayout_12.addLayout(self.verticalLayout_13)
        self.verticalLayout_14.addLayout(self.verticalLayout_12)
        self.tabWidget.addTab(self.tab_build_control, "")
        self.tab_file_ver_info = QtWidgets.QWidget()
        self.tab_file_ver_info.setObjectName("tab_file_ver_info")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.tab_file_ver_info)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.horizontalLayout_23 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_23.setObjectName("horizontalLayout_23")
        self.label_12 = QtWidgets.QLabel(self.tab_file_ver_info)
        self.label_12.setMinimumSize(QtCore.QSize(90, 0))
        self.label_12.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_12.setObjectName("label_12")
        self.horizontalLayout_23.addWidget(self.label_12)
        self.le_file_description = QtWidgets.QLineEdit(self.tab_file_ver_info)
        self.le_file_description.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_file_description.setObjectName("le_file_description")
        self.horizontalLayout_23.addWidget(self.le_file_description)
        self.verticalLayout_7.addLayout(self.horizontalLayout_23)
        self.horizontalLayout_24 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_24.setObjectName("horizontalLayout_24")
        self.label_25 = QtWidgets.QLabel(self.tab_file_ver_info)
        self.label_25.setMinimumSize(QtCore.QSize(90, 0))
        self.label_25.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_25.setObjectName("label_25")
        self.horizontalLayout_24.addWidget(self.label_25)
        self.le_company_name = QtWidgets.QLineEdit(self.tab_file_ver_info)
        self.le_company_name.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_company_name.setObjectName("le_company_name")
        self.horizontalLayout_24.addWidget(self.le_company_name)
        self.verticalLayout_7.addLayout(self.horizontalLayout_24)
        self.horizontalLayout_25 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_25.setObjectName("horizontalLayout_25")
        self.label_19 = QtWidgets.QLabel(self.tab_file_ver_info)
        self.label_19.setMinimumSize(QtCore.QSize(90, 0))
        self.label_19.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_19.setObjectName("label_19")
        self.horizontalLayout_25.addWidget(self.label_19)
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.le_file_version_0 = QtWidgets.QLineEdit(self.tab_file_ver_info)
        self.le_file_version_0.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_file_version_0.setObjectName("le_file_version_0")
        self.horizontalLayout_10.addWidget(self.le_file_version_0)
        self.le_file_version_1 = QtWidgets.QLineEdit(self.tab_file_ver_info)
        self.le_file_version_1.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_file_version_1.setObjectName("le_file_version_1")
        self.horizontalLayout_10.addWidget(self.le_file_version_1)
        self.le_file_version_2 = QtWidgets.QLineEdit(self.tab_file_ver_info)
        self.le_file_version_2.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_file_version_2.setObjectName("le_file_version_2")
        self.horizontalLayout_10.addWidget(self.le_file_version_2)
        self.le_file_version_3 = QtWidgets.QLineEdit(self.tab_file_ver_info)
        self.le_file_version_3.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_file_version_3.setObjectName("le_file_version_3")
        self.horizontalLayout_10.addWidget(self.le_file_version_3)
        self.horizontalLayout_25.addLayout(self.horizontalLayout_10)
        self.verticalLayout_7.addLayout(self.horizontalLayout_25)
        self.horizontalLayout_26 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_26.setObjectName("horizontalLayout_26")
        self.label_20 = QtWidgets.QLabel(self.tab_file_ver_info)
        self.label_20.setMinimumSize(QtCore.QSize(90, 0))
        self.label_20.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_20.setObjectName("label_20")
        self.horizontalLayout_26.addWidget(self.label_20)
        self.le_product_name = QtWidgets.QLineEdit(self.tab_file_ver_info)
        self.le_product_name.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_product_name.setObjectName("le_product_name")
        self.horizontalLayout_26.addWidget(self.le_product_name)
        self.verticalLayout_7.addLayout(self.horizontalLayout_26)
        self.horizontalLayout_27 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_27.setObjectName("horizontalLayout_27")
        self.label_21 = QtWidgets.QLabel(self.tab_file_ver_info)
        self.label_21.setMinimumSize(QtCore.QSize(90, 0))
        self.label_21.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_21.setObjectName("label_21")
        self.horizontalLayout_27.addWidget(self.label_21)
        self.horizontalLayout_22 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_22.setObjectName("horizontalLayout_22")
        self.le_product_version_0 = QtWidgets.QLineEdit(self.tab_file_ver_info)
        self.le_product_version_0.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_product_version_0.setObjectName("le_product_version_0")
        self.horizontalLayout_22.addWidget(self.le_product_version_0)
        self.le_product_version_1 = QtWidgets.QLineEdit(self.tab_file_ver_info)
        self.le_product_version_1.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_product_version_1.setObjectName("le_product_version_1")
        self.horizontalLayout_22.addWidget(self.le_product_version_1)
        self.le_product_version_2 = QtWidgets.QLineEdit(self.tab_file_ver_info)
        self.le_product_version_2.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_product_version_2.setObjectName("le_product_version_2")
        self.horizontalLayout_22.addWidget(self.le_product_version_2)
        self.le_product_version_3 = QtWidgets.QLineEdit(self.tab_file_ver_info)
        self.le_product_version_3.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_product_version_3.setObjectName("le_product_version_3")
        self.horizontalLayout_22.addWidget(self.le_product_version_3)
        self.horizontalLayout_27.addLayout(self.horizontalLayout_22)
        self.verticalLayout_7.addLayout(self.horizontalLayout_27)
        self.horizontalLayout_28 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_28.setObjectName("horizontalLayout_28")
        self.label_22 = QtWidgets.QLabel(self.tab_file_ver_info)
        self.label_22.setMinimumSize(QtCore.QSize(90, 0))
        self.label_22.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_22.setObjectName("label_22")
        self.horizontalLayout_28.addWidget(self.label_22)
        self.le_legal_copyright = QtWidgets.QLineEdit(self.tab_file_ver_info)
        self.le_legal_copyright.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_legal_copyright.setObjectName("le_legal_copyright")
        self.horizontalLayout_28.addWidget(self.le_legal_copyright)
        self.verticalLayout_7.addLayout(self.horizontalLayout_28)
        self.horizontalLayout_29 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_29.setObjectName("horizontalLayout_29")
        self.label_23 = QtWidgets.QLabel(self.tab_file_ver_info)
        self.label_23.setMinimumSize(QtCore.QSize(90, 0))
        self.label_23.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_23.setObjectName("label_23")
        self.horizontalLayout_29.addWidget(self.label_23)
        self.le_legal_trademarks = QtWidgets.QLineEdit(self.tab_file_ver_info)
        self.le_legal_trademarks.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_legal_trademarks.setObjectName("le_legal_trademarks")
        self.horizontalLayout_29.addWidget(self.le_legal_trademarks)
        self.verticalLayout_7.addLayout(self.horizontalLayout_29)
        self.horizontalLayout_30 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_30.setObjectName("horizontalLayout_30")
        self.label_24 = QtWidgets.QLabel(self.tab_file_ver_info)
        self.label_24.setMinimumSize(QtCore.QSize(90, 0))
        self.label_24.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_24.setObjectName("label_24")
        self.horizontalLayout_30.addWidget(self.label_24)
        self.le_original_filename = QtWidgets.QLineEdit(self.tab_file_ver_info)
        self.le_original_filename.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_original_filename.setObjectName("le_original_filename")
        self.horizontalLayout_30.addWidget(self.le_original_filename)
        self.verticalLayout_7.addLayout(self.horizontalLayout_30)
        spacerItem = QtWidgets.QSpacerItem(20, 373, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_7.addItem(spacerItem)
        self.tabWidget.addTab(self.tab_file_ver_info, "")
        self.tab_advanced_setup = QtWidgets.QWidget()
        self.tab_advanced_setup.setObjectName("tab_advanced_setup")
        self.verticalLayout_25 = QtWidgets.QVBoxLayout(self.tab_advanced_setup)
        self.verticalLayout_25.setObjectName("verticalLayout_25")
        self.verticalLayout_24 = QtWidgets.QVBoxLayout()
        self.verticalLayout_24.setObjectName("verticalLayout_24")
        self.groupBox = QtWidgets.QGroupBox(self.tab_advanced_setup)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_22 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_22.setObjectName("verticalLayout_22")
        self.verticalLayout_21 = QtWidgets.QVBoxLayout()
        self.verticalLayout_21.setObjectName("verticalLayout_21")
        self.cb_db_imports = QtWidgets.QCheckBox(self.groupBox)
        self.cb_db_imports.setObjectName("cb_db_imports")
        self.verticalLayout_21.addWidget(self.cb_db_imports)
        self.cb_db_bootloader = QtWidgets.QCheckBox(self.groupBox)
        self.cb_db_bootloader.setObjectName("cb_db_bootloader")
        self.verticalLayout_21.addWidget(self.cb_db_bootloader)
        self.cb_db_noarchive = QtWidgets.QCheckBox(self.groupBox)
        self.cb_db_noarchive.setObjectName("cb_db_noarchive")
        self.verticalLayout_21.addWidget(self.cb_db_noarchive)
        self.verticalLayout_22.addLayout(self.verticalLayout_21)
        self.verticalLayout_24.addWidget(self.groupBox)
        self.groupBox_2 = QtWidgets.QGroupBox(self.tab_advanced_setup)
        self.groupBox_2.setObjectName("groupBox_2")
        self.verticalLayout_23 = QtWidgets.QVBoxLayout(self.groupBox_2)
        self.verticalLayout_23.setObjectName("verticalLayout_23")
        self.le_runtime_tmpdir = QtWidgets.QLineEdit(self.groupBox_2)
        self.le_runtime_tmpdir.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.le_runtime_tmpdir.setObjectName("le_runtime_tmpdir")
        self.verticalLayout_23.addWidget(self.le_runtime_tmpdir)
        self.verticalLayout_24.addWidget(self.groupBox_2)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_24.addItem(spacerItem1)
        self.verticalLayout_25.addLayout(self.verticalLayout_24)
        self.tabWidget.addTab(self.tab_advanced_setup, "")
        self.tab_pyitool_settings = QtWidgets.QWidget()
        self.tab_pyitool_settings.setObjectName("tab_pyitool_settings")
        self.verticalLayout_35 = QtWidgets.QVBoxLayout(self.tab_pyitool_settings)
        self.verticalLayout_35.setObjectName("verticalLayout_35")
        self.verticalLayout_34 = QtWidgets.QVBoxLayout()
        self.verticalLayout_34.setObjectName("verticalLayout_34")
        self.verticalLayout_33 = QtWidgets.QVBoxLayout()
        self.verticalLayout_33.setObjectName("verticalLayout_33")
        self.groupBox_3 = QtWidgets.QGroupBox(self.tab_pyitool_settings)
        self.groupBox_3.setObjectName("groupBox_3")
        self.verticalLayout_31 = QtWidgets.QVBoxLayout(self.groupBox_3)
        self.verticalLayout_31.setObjectName("verticalLayout_31")
        self.verticalLayout_20 = QtWidgets.QVBoxLayout()
        self.verticalLayout_20.setObjectName("verticalLayout_20")
        self.cb_explorer_show = QtWidgets.QCheckBox(self.groupBox_3)
        self.cb_explorer_show.setObjectName("cb_explorer_show")
        self.verticalLayout_20.addWidget(self.cb_explorer_show)
        self.cb_delete_spec_file = QtWidgets.QCheckBox(self.groupBox_3)
        self.cb_delete_spec_file.setObjectName("cb_delete_spec_file")
        self.verticalLayout_20.addWidget(self.cb_delete_spec_file)
        self.cb_delete_working_dir = QtWidgets.QCheckBox(self.groupBox_3)
        self.cb_delete_working_dir.setObjectName("cb_delete_working_dir")
        self.verticalLayout_20.addWidget(self.cb_delete_working_dir)
        self.verticalLayout_31.addLayout(self.verticalLayout_20)
        self.verticalLayout_33.addWidget(self.groupBox_3)
        self.groupBox_4 = QtWidgets.QGroupBox(self.tab_pyitool_settings)
        self.groupBox_4.setObjectName("groupBox_4")
        self.verticalLayout_32 = QtWidgets.QVBoxLayout(self.groupBox_4)
        self.verticalLayout_32.setObjectName("verticalLayout_32")
        self.verticalLayout_30 = QtWidgets.QVBoxLayout()
        self.verticalLayout_30.setObjectName("verticalLayout_30")
        self.verticalLayout_26 = QtWidgets.QVBoxLayout()
        self.verticalLayout_26.setSpacing(2)
        self.verticalLayout_26.setObjectName("verticalLayout_26")
        self.label_28 = QtWidgets.QLabel(self.groupBox_4)
        self.label_28.setObjectName("label_28")
        self.verticalLayout_26.addWidget(self.label_28)
        self.horizontalLayout_32 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_32.setObjectName("horizontalLayout_32")
        self.uiLineEdit_config_remark = QtWidgets.QLineEdit(self.groupBox_4)
        self.uiLineEdit_config_remark.setObjectName("uiLineEdit_config_remark")
        self.horizontalLayout_32.addWidget(self.uiLineEdit_config_remark)
        self.uiPushButton_save_config = QtWidgets.QPushButton(self.groupBox_4)
        self.uiPushButton_save_config.setObjectName("uiPushButton_save_config")
        self.horizontalLayout_32.addWidget(self.uiPushButton_save_config)
        self.verticalLayout_26.addLayout(self.horizontalLayout_32)
        self.verticalLayout_30.addLayout(self.verticalLayout_26)
        self.verticalLayout_27 = QtWidgets.QVBoxLayout()
        self.verticalLayout_27.setSpacing(2)
        self.verticalLayout_27.setObjectName("verticalLayout_27")
        self.label_29 = QtWidgets.QLabel(self.groupBox_4)
        self.label_29.setObjectName("label_29")
        self.verticalLayout_27.addWidget(self.label_29)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.uiComboBox_saved_config = QtWidgets.QComboBox(self.groupBox_4)
        self.uiComboBox_saved_config.setObjectName("uiComboBox_saved_config")
        self.uiComboBox_saved_config.addItem("")
        self.horizontalLayout_7.addWidget(self.uiComboBox_saved_config)
        self.uiPushButton_delete_config = QtWidgets.QPushButton(self.groupBox_4)
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(255, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(120, 120, 120))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.ButtonText, brush)
        self.uiPushButton_delete_config.setPalette(palette)
        self.uiPushButton_delete_config.setObjectName("uiPushButton_delete_config")
        self.horizontalLayout_7.addWidget(self.uiPushButton_delete_config)
        self.uiPushButton_apply_config = QtWidgets.QPushButton(self.groupBox_4)
        self.uiPushButton_apply_config.setObjectName("uiPushButton_apply_config")
        self.horizontalLayout_7.addWidget(self.uiPushButton_apply_config)
        self.horizontalLayout_7.setStretch(0, 1)
        self.verticalLayout_27.addLayout(self.horizontalLayout_7)
        self.verticalLayout_30.addLayout(self.verticalLayout_27)
        self.verticalLayout_32.addLayout(self.verticalLayout_30)
        self.verticalLayout_33.addWidget(self.groupBox_4)
        self.verticalLayout_34.addLayout(self.verticalLayout_33)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_34.addItem(spacerItem2)
        self.verticalLayout_35.addLayout(self.verticalLayout_34)
        self.tabWidget.addTab(self.tab_pyitool_settings, "")
        self.layoutWidget = QtWidgets.QWidget(self.splitter)
        self.layoutWidget.setObjectName("layoutWidget")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.layoutWidget)
        self.verticalLayout_6.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setSpacing(4)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.lb_platform_info = QtWidgets.QLabel(self.layoutWidget)
        self.lb_platform_info.setMinimumSize(QtCore.QSize(0, 24))
        self.lb_platform_info.setFrameShape(QtWidgets.QFrame.Box)
        self.lb_platform_info.setObjectName("lb_platform_info")
        self.gridLayout_2.addWidget(self.lb_platform_info, 2, 1, 1, 1)
        self.label_16 = QtWidgets.QLabel(self.layoutWidget)
        self.label_16.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_16.setObjectName("label_16")
        self.gridLayout_2.addWidget(self.label_16, 0, 0, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.lb_py_info = QtWidgets.QLabel(self.layoutWidget)
        self.lb_py_info.setFrameShape(QtWidgets.QFrame.Box)
        self.lb_py_info.setObjectName("lb_py_info")
        self.horizontalLayout.addWidget(self.lb_py_info)
        self.pb_select_py_env = QtWidgets.QPushButton(self.layoutWidget)
        self.pb_select_py_env.setObjectName("pb_select_py_env")
        self.horizontalLayout.addWidget(self.pb_select_py_env)
        self.horizontalLayout.setStretch(0, 9)
        self.gridLayout_2.addLayout(self.horizontalLayout, 1, 1, 1, 1)
        self.cb_prioritize_venv = QtWidgets.QCheckBox(self.layoutWidget)
        self.cb_prioritize_venv.setObjectName("cb_prioritize_venv")
        self.gridLayout_2.addWidget(self.cb_prioritize_venv, 3, 1, 1, 1)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.lb_pyi_info = QtWidgets.QLabel(self.layoutWidget)
        self.lb_pyi_info.setFrameShape(QtWidgets.QFrame.Box)
        self.lb_pyi_info.setObjectName("lb_pyi_info")
        self.horizontalLayout_2.addWidget(self.lb_pyi_info)
        self.pb_reinstall_pyi = QtWidgets.QPushButton(self.layoutWidget)
        self.pb_reinstall_pyi.setObjectName("pb_reinstall_pyi")
        self.horizontalLayout_2.addWidget(self.pb_reinstall_pyi)
        self.horizontalLayout_2.setStretch(0, 9)
        self.gridLayout_2.addLayout(self.horizontalLayout_2, 0, 1, 1, 1)
        self.label_15 = QtWidgets.QLabel(self.layoutWidget)
        self.label_15.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_15.setObjectName("label_15")
        self.gridLayout_2.addWidget(self.label_15, 2, 0, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.layoutWidget)
        self.label_6.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_6.setObjectName("label_6")
        self.gridLayout_2.addWidget(self.label_6, 1, 0, 1, 1)
        self.verticalLayout_6.addLayout(self.gridLayout_2)
        self.line_5 = QtWidgets.QFrame(self.layoutWidget)
        self.line_5.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_5.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_5.setObjectName("line_5")
        self.verticalLayout_6.addWidget(self.line_5)
        self.verticalLayout_16 = QtWidgets.QVBoxLayout()
        self.verticalLayout_16.setObjectName("verticalLayout_16")
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        self.label_5 = QtWidgets.QLabel(self.layoutWidget)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_17.addWidget(self.label_5)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setSpacing(0)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.label_18 = QtWidgets.QLabel(self.layoutWidget)
        self.label_18.setObjectName("label_18")
        self.horizontalLayout_8.addWidget(self.label_18)
        self.cb_log_level = QtWidgets.QComboBox(self.layoutWidget)
        self.cb_log_level.setObjectName("cb_log_level")
        self.cb_log_level.addItem("")
        self.cb_log_level.addItem("")
        self.cb_log_level.addItem("")
        self.cb_log_level.addItem("")
        self.cb_log_level.addItem("")
        self.cb_log_level.addItem("")
        self.horizontalLayout_8.addWidget(self.cb_log_level)
        self.horizontalLayout_17.addLayout(self.horizontalLayout_8)
        self.horizontalLayout_17.setStretch(0, 9)
        self.verticalLayout_16.addLayout(self.horizontalLayout_17)
        self.te_pyi_out_stream = QtWidgets.QTextEdit(self.layoutWidget)
        self.te_pyi_out_stream.setMinimumSize(QtCore.QSize(0, 456))
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(10)
        self.te_pyi_out_stream.setFont(font)
        self.te_pyi_out_stream.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.te_pyi_out_stream.setLineWrapMode(QtWidgets.QTextEdit.NoWrap)
        self.te_pyi_out_stream.setReadOnly(True)
        self.te_pyi_out_stream.setObjectName("te_pyi_out_stream")
        self.verticalLayout_16.addWidget(self.te_pyi_out_stream)
        self.verticalLayout_6.addLayout(self.verticalLayout_16)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.lb_running_gif = QtWidgets.QLabel(self.layoutWidget)
        self.lb_running_gif.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lb_running_gif.setObjectName("lb_running_gif")
        self.horizontalLayout_4.addWidget(self.lb_running_gif)
        self.lb_running_tip = QtWidgets.QLabel(self.layoutWidget)
        self.lb_running_tip.setObjectName("lb_running_tip")
        self.horizontalLayout_4.addWidget(self.lb_running_tip)
        self.horizontalLayout_4.setStretch(1, 1)
        self.verticalLayout_6.addLayout(self.horizontalLayout_4)
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_18.setSpacing(4)
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        self.pb_check_imports = QtWidgets.QPushButton(self.layoutWidget)
        self.pb_check_imports.setMinimumSize(QtCore.QSize(0, 50))
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(255, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(120, 120, 120))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.ButtonText, brush)
        self.pb_check_imports.setPalette(palette)
        font = QtGui.QFont()
        font.setFamily("Microsoft YaHei UI")
        font.setPointSize(10)
        self.pb_check_imports.setFont(font)
        self.pb_check_imports.setObjectName("pb_check_imports")
        self.horizontalLayout_18.addWidget(self.pb_check_imports)
        self.pb_gen_executable = QtWidgets.QPushButton(self.layoutWidget)
        self.pb_gen_executable.setMinimumSize(QtCore.QSize(0, 50))
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(120, 120, 120))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.ButtonText, brush)
        self.pb_gen_executable.setPalette(palette)
        font = QtGui.QFont()
        font.setFamily("Microsoft YaHei UI")
        font.setPointSize(12)
        self.pb_gen_executable.setFont(font)
        self.pb_gen_executable.setObjectName("pb_gen_executable")
        self.horizontalLayout_18.addWidget(self.pb_gen_executable)
        self.horizontalLayout_18.setStretch(0, 1)
        self.horizontalLayout_18.setStretch(1, 2)
        self.verticalLayout_6.addLayout(self.horizontalLayout_18)
        self.verticalLayout_18.addWidget(self.splitter)
        pyinstaller_tool.setCentralWidget(self.centralwidget)

        self.retranslateUi(pyinstaller_tool)
        self.tabWidget.setCurrentIndex(0)
        self.uiComboBox_saved_config.setCurrentIndex(0)
        self.cb_log_level.setCurrentIndex(2)
        QtCore.QMetaObject.connectSlotsByName(pyinstaller_tool)

    def retranslateUi(self, pyinstaller_tool):
        _translate = QtCore.QCoreApplication.translate
        pyinstaller_tool.setWindowTitle(_translate("pyinstaller_tool", "程序打包工具"))
        self.label.setText(_translate("pyinstaller_tool", "程序启动入口："))
        self.le_program_entry_old.setToolTip(_translate("pyinstaller_tool", "要打包的程序的启动入口(*.py *.pyw *.pyc *.spec)，此项必填。\n"
"如果指定了SPEC文件，则以下绝大部分项目文件及生成控制都将不生效。"))
        self.pb_select_program_entry.setText(_translate("pyinstaller_tool", "选择"))
        self.label_13.setText(_translate("pyinstaller_tool", "打包后的文件名（不含后缀）："))
        self.le_output_name.setToolTip(_translate("pyinstaller_tool", "对应选项：-n, --name\n"
"打包完成后的 exe 可执行文件文件的名称，此项留空则使用程序启动入口文件名。"))
        self.label_2.setText(_translate("pyinstaller_tool", "源代码根目录 / 相对路径起点："))
        self.pb_reset_root_level.setToolTip(_translate("pyinstaller_tool", "将源代码根目录重置为程序启动入口所在目录。"))
        self.pb_reset_root_level.setText(_translate("pyinstaller_tool", "重置"))
        self.pb_up_level_root.setToolTip(_translate("pyinstaller_tool", "将源代码根目录向上移一级。"))
        self.pb_up_level_root.setText(_translate("pyinstaller_tool", "上一级"))
        self.le_project_root.setToolTip(_translate("pyinstaller_tool", "当前的源代码根目录，选择程序启动入口文件后自动确定。"))
        self.label_26.setText(_translate("pyinstaller_tool", "隐蔽的导入："))
        self.pb_clear_hidden_imports.setText(_translate("pyinstaller_tool", "清空"))
        self.pte_hidden_imports.setToolTip(_translate("pyinstaller_tool", "对应选项：--hidden-import, --hiddenimport\n"
"某些模块可能会被通过隐蔽的方式导入导致 Pyinstaller 没有发现它，将没有被发现的模块名填入此处以使 Pyinstaller 主动包含这些模块。\n"
"每行一个模块名称，\"名称\"是指 Python 代码中 import 语句所使用的模块名称，区分大小写。"))
        self.label_27.setText(_translate("pyinstaller_tool", "排除的模块："))
        self.pb_clear_exclude_module.setText(_translate("pyinstaller_tool", "清空"))
        self.pte_exclude_modules.setToolTip(_translate("pyinstaller_tool", "对应选项：--exclude-module\n"
"如果您不想让 Pyinstaller 打包某些模块，则请把模块名称填入此处，每行一个。\n"
"以上\"名称\"是指 Python 代码中 import 语句所使用的模块名称，区分大小写。"))
        self.label_3.setText(_translate("pyinstaller_tool", "其他模块搜索目录："))
        self.pb_clear_module_search_path.setToolTip(_translate("pyinstaller_tool", "清空其他模块搜索目录文本框。"))
        self.pb_clear_module_search_path.setText(_translate("pyinstaller_tool", "清空"))
        self.pb_select_module_search_path.setText(_translate("pyinstaller_tool", "选择"))
        self.label_4.setText(_translate("pyinstaller_tool", "非源代码资源文件："))
        self.pb_clear_other_data.setText(_translate("pyinstaller_tool", "清空"))
        self.pb_select_other_data.setText(_translate("pyinstaller_tool", "选择"))
        self.label_7.setText(_translate("pyinstaller_tool", "可执行文件的图标路径："))
        self.pb_select_file_icon.setText(_translate("pyinstaller_tool", "选择"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_project_files), _translate("pyinstaller_tool", "项目文件"))
        self.rb_pack_to_one_dir.setToolTip(_translate("pyinstaller_tool", "对应选项：-D, --onedir\n"
"将程序打包成单文件夹形式，exe 可执行程序在文件夹的首层目录内。"))
        self.rb_pack_to_one_dir.setText(_translate("pyinstaller_tool", "打包成单目录"))
        self.rb_pack_to_one_file.setToolTip(_translate("pyinstaller_tool", "对应选项；-F, --onefile\n"
"将程序以及添加的其他资源文件打包成单一文件的形式，启动速度稍慢。"))
        self.rb_pack_to_one_file.setText(_translate("pyinstaller_tool", "打包成单文件"))
        self.cb_execute_with_console.setToolTip(_translate("pyinstaller_tool", "勾选时对应选项：-c, --console, --nowindowed\n"
"不勾选时对应选项：-w, --windowed, --noconsole\n"
"打包完成后启动程序是否显示命令行窗口，注意，后缀为 .pyw 的程序启动入口打包后不显示控制台，此项设置失效。"))
        self.cb_execute_with_console.setText(_translate("pyinstaller_tool", "打包的程序运行时显示控制台"))
        self.cb_without_confirm.setToolTip(_translate("pyinstaller_tool", "对应选项：-y, --noconfirm\n"
"打包时如果预定的 exe 文件储存目录不为空，是清空该目录还是中断打包过程。"))
        self.cb_without_confirm.setText(_translate("pyinstaller_tool", "输出目录不为空时清空而不是中断"))
        self.cb_use_upx.setToolTip(_translate("pyinstaller_tool", "不勾选时对应选项：--noupx\n"
"打包过程中是否使用 upx 对文件进行压缩。注意，某些二进制文件在经过 upx 压缩后可能无法正常运行。\n"
"仅当系统环境变量 PATH 中有 upx 所在目录信息或在以下“upx 可执行文件所在目录”指定了 upx 所在目录时，此项设置才生效。"))
        self.cb_use_upx.setText(_translate("pyinstaller_tool", "使用 upx 对文件进行压缩"))
        self.cb_clean_before_build.setToolTip(_translate("pyinstaller_tool", "对应选项：--clean\n"
"打包前是否清空 Pyinstaller 生成的临时文件夹（临时文件可使下次打包加速）。"))
        self.cb_clean_before_build.setText(_translate("pyinstaller_tool", "打包前清理缓存并删除临时文件"))
        self.cb_write_info_to_exec.setToolTip(_translate("pyinstaller_tool", "对应选项：--version-file\n"
"勾选此选项则将\"附加信息\"标签页中的内容写入生成的 exe 文件，这些信息可以在查看 exe 文件属性时看见。"))
        self.cb_write_info_to_exec.setText(_translate("pyinstaller_tool", "将“附加信息”标签页的内容写入生成的可执行文件"))
        self.cb_uac_admin.setToolTip(_translate("pyinstaller_tool", "对应选项：--uac-admin\n"
"使打包的 exe 程序启动时请求提升权限，打包需要管理员权限才能正常工作的程序时，请勾选此选项。"))
        self.cb_uac_admin.setText(_translate("pyinstaller_tool", "打包的程序启动时请求提升权限"))
        self.label_11.setText(_translate("pyinstaller_tool", "字节码加密秘钥："))
        self.le_bytecode_encryption_key.setToolTip(_translate("pyinstaller_tool", "对应选项：--key\n"
"用于加密 Python 字节码的密钥，此项可留空。"))
        self.label_8.setText(_translate("pyinstaller_tool", "打包后的文件储存位置："))
        self.le_output_dir.setToolTip(_translate("pyinstaller_tool", "对应选项：--distpath\n"
"此项可留空，默认储存位置：\"源代码根目录/dist\"。"))
        self.pb_select_output_dir.setText(_translate("pyinstaller_tool", "选择"))
        self.label_17.setText(_translate("pyinstaller_tool", "spec 文件储存位置："))
        self.le_spec_dir.setToolTip(_translate("pyinstaller_tool", "对应选项：--specpath\n"
"此项可留空，默认储存位置：\"源代码根目录\"。"))
        self.pb_select_spec_dir.setText(_translate("pyinstaller_tool", "选择"))
        self.label_10.setText(_translate("pyinstaller_tool", "临时工作目录所在位置："))
        self.le_temp_working_dir.setToolTip(_translate("pyinstaller_tool", "对应选项：--workpath\n"
"此项可留空，默认目录：\"源代码根目录/build\"。"))
        self.pb_select_temp_working_dir.setText(_translate("pyinstaller_tool", "选择"))
        self.label_9.setText(_translate("pyinstaller_tool", "upx 可执行文件所在目录："))
        self.le_upx_search_path.setToolTip(_translate("pyinstaller_tool", "对应选项：--upx-dir\n"
"此项可留空，找不到 upx 时将不进行压缩。当系统环境变量 PATH 中有 upx 路径时，不需要指定此选项也可使用 upx。"))
        self.pb_select_upx_search_path.setText(_translate("pyinstaller_tool", "选择"))
        self.label_14.setText(_translate("pyinstaller_tool", "upx 压缩时排除的文件名："))
        self.te_upx_exclude_files.setToolTip(_translate("pyinstaller_tool", "对应选项：--upx-exclude\n"
"使用 upx 进行压缩时需要忽略的文件，每行一个不含路径的文件名。\n"
"某些二进制文件经过 upx 压缩后可能无法运行，可将这些文件名添加到此处以使 upx 在压缩时略过。"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_build_control), _translate("pyinstaller_tool", "打包控制"))
        self.tab_file_ver_info.setToolTip(_translate("pyinstaller_tool", "需要在\"生成控制\"中勾选\"将文件信息写入生成的可执行文件\"，此设置才生效。\n"
"生成的可执行文件的附加信息，即鼠标悬停于exe文件上显示的信息，以及exe文件属性中的详细信息。"))
        self.label_12.setText(_translate("pyinstaller_tool", "文件说明："))
        self.label_25.setText(_translate("pyinstaller_tool", "公司："))
        self.label_19.setText(_translate("pyinstaller_tool", "文件版本："))
        self.label_20.setText(_translate("pyinstaller_tool", "产品名称："))
        self.label_21.setText(_translate("pyinstaller_tool", "产品版本："))
        self.label_22.setText(_translate("pyinstaller_tool", "版权："))
        self.label_23.setText(_translate("pyinstaller_tool", "合法商标："))
        self.label_24.setText(_translate("pyinstaller_tool", "原始文件名："))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_file_ver_info), _translate("pyinstaller_tool", "附加信息"))
        self.groupBox.setTitle(_translate("pyinstaller_tool", "以调试模式打包程序"))
        self.cb_db_imports.setToolTip(_translate("pyinstaller_tool", "对应选项：-d {imports}, --debug {imports}\n"
"每次初始化模块时，打印一条消息，显示加载该模块的位置(文件名或内置模块)。\n"
"要求源代码文件后缀名不能是 *.pyw，\"生成控制\"标签中的\"打包的程序运行时显示控制台\"选项必须勾选。"))
        self.cb_db_imports.setText(_translate("pyinstaller_tool", "运行时输出模块导入信息"))
        self.cb_db_bootloader.setToolTip(_translate("pyinstaller_tool", "对应选项：-d {bootloader}, --debug {bootloader}\n"
"使引导程序在初始化和启动捆绑的应用程序时发出进度消息，用于诊断导入丢失的问题。\n"
"要求源代码文件后缀名不能是 *.pyw，\"生成控制\"标签中的\"打包的程序运行时显示控制台\"选项必须勾选。"))
        self.cb_db_bootloader.setText(_translate("pyinstaller_tool", "运行时输出引导进度信息"))
        self.cb_db_noarchive.setToolTip(_translate("pyinstaller_tool", "对应选项：-d {noarchive}, --debug {noarchive}\n"
"不将所有冻结的源代码文件存档在生成的可执行文件中，而是将它们作为单独的文件存储在生成的输出目录中。"))
        self.cb_db_noarchive.setText(_translate("pyinstaller_tool", "不将源文件存档至可执行文件中"))
        self.groupBox_2.setTitle(_translate("pyinstaller_tool", "打包单文件运行时临时目录"))
        self.le_runtime_tmpdir.setToolTip(_translate("pyinstaller_tool", "对应选项：--runtime-tmpdir\n"
"以\"单文件\"模式打包的程序运行时提取的库和支持文件的临时储存位置。\n"
"如果指定了此选项，则引导加载程序将忽略运行时操作系统定义的任何临时文件夹位置，\"_MEIxxxxxx\"文件夹将在您指定的位置创建。\n"
"仅当您知道自己在做什么时，才使用此选项。"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_advanced_setup), _translate("pyinstaller_tool", "高级设置"))
        self.groupBox_3.setTitle(_translate("pyinstaller_tool", "打包成功后执行..."))
        self.cb_explorer_show.setToolTip(_translate("pyinstaller_tool", "打包成功后打开资源管理器并选中打包好的 .exe 文件，如果打包失败则不会打开资源管理器。"))
        self.cb_explorer_show.setText(_translate("pyinstaller_tool", "在资源管理器中显示"))
        self.cb_delete_spec_file.setToolTip(_translate("pyinstaller_tool", "打包成功后删除 Pyinstaller 生成的 .spec 文件，打包失败则不会执行删除操作。"))
        self.cb_delete_spec_file.setText(_translate("pyinstaller_tool", "删除 spec 文件"))
        self.cb_delete_working_dir.setToolTip(_translate("pyinstaller_tool", "打包成功后删除临时工作文件夹，打包失败则不会执行删除操作。\n"
"如果你没有自定义临时工作目录所在目录，则临时工作目录指的就是源代码根目录下的 build 目录。"))
        self.cb_delete_working_dir.setText(_translate("pyinstaller_tool", "删除临时工作文件夹"))
        self.groupBox_4.setTitle(_translate("pyinstaller_tool", "打包配置管理"))
        self.label_28.setText(_translate("pyinstaller_tool", "保存当前打包配置"))
        self.uiLineEdit_config_remark.setToolTip(_translate("pyinstaller_tool", "当前打包配置是指“程序打包工具”所有复选框、输入框等控件的设置状态。\n"
"输入一个你容易记住的备注名称并点击“保存”按钮将这些设置保存下来以便在不同的打包项目之间快速切换。"))
        self.uiLineEdit_config_remark.setPlaceholderText(_translate("pyinstaller_tool", "请输入配置的备注名称"))
        self.uiPushButton_save_config.setToolTip(_translate("pyinstaller_tool", "将“程序打包工具”当前复选框、输入框等控件设置状态保存下来，以左侧输入框内容作为这个保存下来的配置的名称。"))
        self.uiPushButton_save_config.setText(_translate("pyinstaller_tool", "保存"))
        self.label_29.setText(_translate("pyinstaller_tool", "已保存的打包配置"))
        self.uiComboBox_saved_config.setToolTip(_translate("pyinstaller_tool", "所有已保存的配置，这里显示的是你在保存配置时输入的备注名称。"))
        self.uiComboBox_saved_config.setItemText(0, _translate("pyinstaller_tool", "当前打包配置"))
        self.uiPushButton_delete_config.setToolTip(_translate("pyinstaller_tool", "将左侧下拉选择框选中的配置删除。"))
        self.uiPushButton_delete_config.setText(_translate("pyinstaller_tool", "删除"))
        self.uiPushButton_apply_config.setToolTip(_translate("pyinstaller_tool", "将左侧下拉选择框选中的配置内容应用到“程序打包”工具。"))
        self.uiPushButton_apply_config.setText(_translate("pyinstaller_tool", "应用"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_pyitool_settings), _translate("pyinstaller_tool", "工具设置"))
        self.lb_platform_info.setToolTip(_translate("pyinstaller_tool", "操作系统的版本信息。"))
        self.label_16.setText(_translate("pyinstaller_tool", "Pyi 版本"))
        self.lb_py_info.setToolTip(_translate("pyinstaller_tool", "当前选择的 Python 环境的版本信息。\n"
"选择不同 Python 环境时，在该环境中也应安装运行项目所需的所有模块。"))
        self.pb_select_py_env.setToolTip(_translate("pyinstaller_tool", "选择在不同 Python 环境中将程序打包成可执行文件。\n"
"如果可选条目为空，需要先在\"包管理器\"中添加本机 Python 环境。\n"
"选择不同 Python 环境时，在该环境中也应安装运行项目所需的所有模块。"))
        self.pb_select_py_env.setText(_translate("pyinstaller_tool", "选择环境"))
        self.cb_prioritize_venv.setText(_translate("pyinstaller_tool", "使用项目目录下的虚拟环境而不是以上环境"))
        self.lb_pyi_info.setToolTip(_translate("pyinstaller_tool", "所选 Python 环境下的 Pyinstaller 的版本信息。"))
        self.pb_reinstall_pyi.setToolTip(_translate("pyinstaller_tool", "在当前选择的 Python 环境中安装或重新安装 Pyinstaller 。"))
        self.pb_reinstall_pyi.setText(_translate("pyinstaller_tool", "安装"))
        self.label_15.setText(_translate("pyinstaller_tool", "系统信息"))
        self.label_6.setText(_translate("pyinstaller_tool", "打包环境"))
        self.label_5.setToolTip(_translate("pyinstaller_tool", "打包时向控制台输出的详细信息，用于分析打包时出现的问题。"))
        self.label_5.setText(_translate("pyinstaller_tool", "打包信息"))
        self.label_18.setText(_translate("pyinstaller_tool", "级别："))
        self.cb_log_level.setToolTip(_translate("pyinstaller_tool", "对应选项：--log-level\n"
"打包程序时输出的信息量，选择越靠前的选项输出的信息量越大，默认INFO。"))
        self.cb_log_level.setItemText(0, _translate("pyinstaller_tool", "TRACE"))
        self.cb_log_level.setItemText(1, _translate("pyinstaller_tool", "DEBUG"))
        self.cb_log_level.setItemText(2, _translate("pyinstaller_tool", "INFO"))
        self.cb_log_level.setItemText(3, _translate("pyinstaller_tool", "WARN"))
        self.cb_log_level.setItemText(4, _translate("pyinstaller_tool", "ERROR"))
        self.cb_log_level.setItemText(5, _translate("pyinstaller_tool", "CRITICAL"))
        self.pb_check_imports.setToolTip(_translate("pyinstaller_tool", "检查程序运行所需的所有模块是否在所选的 Python 环境中安装。"))
        self.pb_check_imports.setText(_translate("pyinstaller_tool", "环境检查"))
        self.pb_gen_executable.setToolTip(_translate("pyinstaller_tool", "将 Python 程序及所选资源文件打包成 .exe 可执行文件。"))
        self.pb_gen_executable.setText(_translate("pyinstaller_tool", "开始打包"))



# coding: utf-8

from setuptools import *

from source.awespykit.__info__ import *

description = "一个关于 Python 的 GUI 工具箱：包管理器、程序打包、切换 pip 源、模块安装包下载。"

try:
    with open("README.md", "rt", encoding="utf-8") as md:
        long_description = md.read()
except Exception:
    long_description = description

setup(
    description=description,
    long_description=long_description,
    long_description_content_type="text/markdown",
    name=NAME,
    url=URL,
    author=AUTHOR,
    version=VERSION,
    license="MIT License",
    install_requires=["chardet>=4.0.0", "PyQt5>=5.15.0", "fastpip>=1.3,<2.0"],
    package_dir={"": "source"},
    packages=find_packages("source"),
    python_requires=">=3.7",
    platforms=["win32", "win_amd64"],
    classifiers=[
        "Intended Audience :: Developers",
        "Development Status :: 4 - Beta",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    package_data={"awespykit": ["help/About.html"]},
    entry_points={
        "console_scripts": ["rpk = awespykit.runpykit:run_pykit_sysexit_when_close"]
    },
)



# coding: utf-8

from typing import Sequence

from .abstract_config import AbstractConfig
from .package_manager import get_shared_pypaths


class PackageDownloadConfig(AbstractConfig):
    """模块安装包下载器的设置类"""

    _key_package_names = "package_names"
    _key_derived_from = "derived_from"
    _key_download_deps = "download_deps"
    _key_download_type = "download_type"
    _key_include_pre = "include_pre"
    _key_ignore_requires_python = "ignore_requires_python"
    _key_save_path = "save_path"
    _key_platform = "platform"
    _key_python_version = "python_version"
    _key_implementation = "implementation"
    _key_abis = "abis"
    _key_index_url = "index_url"
    _key_use_index_url = "use_index_url"
    _key_window_size = "window_size"
    _key_dlstatus_winsize = "dlstatus_winsize"

    CONFIGFILE = "package_download.json"

    def __init__(self):
        super().__init__(self.CONFIGFILE)

    @property
    def package_names(self):
        if self._key_package_names not in self:
            self[self._key_package_names] = list()
        return self[self._key_package_names]

    @package_names.setter
    def package_names(self, value):
        assert isinstance(value, list)
        self[self._key_package_names] = value

    @property
    def derived_from(self):
        if self._key_derived_from not in self:
            self[self._key_derived_from] = -1
        return self[self._key_derived_from]

    @derived_from.setter
    def derived_from(self, value):
        assert isinstance(value, int)
        self[self._key_derived_from] = value

    @property
    def download_deps(self):
        if self._key_download_deps not in self:
            self[self._key_download_deps] = True
        return self[self._key_download_deps]

    @download_deps.setter
    def download_deps(self, value):
        assert isinstance(value, bool)
        self[self._key_download_deps] = value

    @property
    def download_type(self):
        if self._key_download_type not in self:
            self[self._key_download_type] = "unlimited"
        return self[self._key_download_type]

    @download_type.setter
    def download_type(self, value):
        assert value in ("unlimited", "no_binary", "only_binary", "prefer_binary")
        self[self._key_download_type] = value

    @property
    def include_pre(self):
        if self._key_include_pre not in self:
            self[self._key_include_pre] = False
        return self[self._key_include_pre]

    @include_pre.setter
    def include_pre(self, value):
        assert isinstance(value, bool)
        self[self._key_include_pre] = value

    @property
    def ignore_requires_python(self):
        if self._key_ignore_requires_python not in self:
            self[self._key_ignore_requires_python] = False
        return self[self._key_ignore_requires_python]

    @ignore_requires_python.setter
    def ignore_requires_python(self, value):
        assert isinstance(value, bool)
        self[self._key_ignore_requires_python] = value

    @property
    def save_path(self):
        if self._key_save_path not in self:
            self[self._key_save_path] = ""
        return self[self._key_save_path]

    @save_path.setter
    def save_path(self, value):
        assert isinstance(value, str)
        self[self._key_save_path] = value

    @property
    def platform(self):
        if self._key_platform not in self:
            self[self._key_platform] = list()
        return self[self._key_platform]

    @platform.setter
    def platform(self, value):
        assert isinstance(value, list)
        self[self._key_platform] = value

    @property
    def python_version(self):
        if self._key_python_version not in self:
            self[self._key_python_version] = ""
        return self[self._key_python_version]

    @python_version.setter
    def python_version(self, value):
        assert isinstance(value, str)
        self[self._key_python_version] = value

    @property
    def implementation(self):
        if self._key_implementation not in self:
            self[self._key_implementation] = ""
        return self[self._key_implementation]

    @implementation.setter
    def implementation(self, value):
        assert isinstance(value, str)
        self[self._key_implementation] = value

    @property
    def abis(self):
        if self._key_abis not in self:
            self[self._key_abis] = list()
        return self[self._key_abis]

    @abis.setter
    def abis(self, value):
        assert isinstance(value, list)
        self[self._key_abis] = value

    @property
    def index_url(self):
        if self._key_index_url not in self:
            self[self._key_index_url] = ""
        return self[self._key_index_url]

    @index_url.setter
    def index_url(self, value):
        assert isinstance(value, str)
        self[self._key_index_url] = value

    @property
    def use_index_url(self):
        if self._key_use_index_url not in self:
            self[self._key_use_index_url] = False
        return self[self._key_use_index_url]

    @use_index_url.setter
    def use_index_url(self, value):
        assert isinstance(value, bool)
        self[self._key_use_index_url] = value

    @property
    def cur_pypaths(self):
        shared_pypaths = get_shared_pypaths()
        if shared_pypaths is None:
            return list()
        assert isinstance(shared_pypaths, list)
        return shared_pypaths

    @property
    def window_size(self):
        if self._key_window_size not in self:
            self[self._key_window_size] = 620, 660
        return self[self._key_window_size]

    @window_size.setter
    def window_size(self, value):
        assert isinstance(value, Sequence)
        assert len(value) == 2
        assert isinstance(value[0], int) and isinstance(value[1], int)
        self[self._key_window_size] = value

    @property
    def dlstatus_winsize(self):
        if self._key_dlstatus_winsize not in self:
            self[self._key_dlstatus_winsize] = 260, 500
        return self[self._key_dlstatus_winsize]

    @dlstatus_winsize.setter
    def dlstatus_winsize(self, value):
        assert isinstance(value, Sequence)
        assert len(value) == 2
        assert isinstance(value[0], int) and isinstance(value[1], int)
        self[self._key_dlstatus_winsize] = value



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'main_entrance.ui'
#
# Created by: PyQt5 UI code generator 5.15.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_main_entrance(object):
    def setupUi(self, main_entrance):
        main_entrance.setObjectName("main_entrance")
        main_entrance.resize(260, 320)
        font = QtGui.QFont()
        font.setFamily("Microsoft YaHei UI")
        font.setPointSize(10)
        main_entrance.setFont(font)
        self.centralwidget = QtWidgets.QWidget(main_entrance)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setContentsMargins(8, 8, 8, 8)
        self.verticalLayout.setObjectName("verticalLayout")
        self.pb_pkg_mgr = QtWidgets.QPushButton(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pb_pkg_mgr.sizePolicy().hasHeightForWidth())
        self.pb_pkg_mgr.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Microsoft YaHei UI")
        font.setPointSize(11)
        self.pb_pkg_mgr.setFont(font)
        self.pb_pkg_mgr.setObjectName("pb_pkg_mgr")
        self.verticalLayout.addWidget(self.pb_pkg_mgr)
        self.pb_pyi_tool = QtWidgets.QPushButton(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pb_pyi_tool.sizePolicy().hasHeightForWidth())
        self.pb_pyi_tool.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Microsoft YaHei UI")
        font.setPointSize(11)
        self.pb_pyi_tool.setFont(font)
        self.pb_pyi_tool.setObjectName("pb_pyi_tool")
        self.verticalLayout.addWidget(self.pb_pyi_tool)
        self.pb_index_mgr = QtWidgets.QPushButton(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pb_index_mgr.sizePolicy().hasHeightForWidth())
        self.pb_index_mgr.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Microsoft YaHei UI")
        font.setPointSize(11)
        self.pb_index_mgr.setFont(font)
        self.pb_index_mgr.setObjectName("pb_index_mgr")
        self.verticalLayout.addWidget(self.pb_index_mgr)
        self.pb_pkg_dload = QtWidgets.QPushButton(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pb_pkg_dload.sizePolicy().hasHeightForWidth())
        self.pb_pkg_dload.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Microsoft YaHei UI")
        font.setPointSize(11)
        self.pb_pkg_dload.setFont(font)
        self.pb_pkg_dload.setObjectName("pb_pkg_dload")
        self.verticalLayout.addWidget(self.pb_pkg_dload)
        main_entrance.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(main_entrance)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 260, 25))
        self.menubar.setObjectName("menubar")
        self.menu_help = QtWidgets.QMenu(self.menubar)
        self.menu_help.setObjectName("menu_help")
        self.menu_settings = QtWidgets.QMenu(self.menubar)
        self.menu_settings.setObjectName("menu_settings")
        self.menu_style = QtWidgets.QMenu(self.menu_settings)
        self.menu_style.setObjectName("menu_style")
        main_entrance.setMenuBar(self.menubar)
        self.description = QtWidgets.QAction(main_entrance)
        font = QtGui.QFont()
        self.description.setFont(font)
        self.description.setObjectName("description")
        self.action_about = QtWidgets.QAction(main_entrance)
        font = QtGui.QFont()
        self.action_about.setFont(font)
        self.action_about.setObjectName("action_about")
        self.contribution = QtWidgets.QAction(main_entrance)
        self.contribution.setObjectName("contribution")
        self.action_fusion = QtWidgets.QAction(main_entrance)
        self.action_fusion.setCheckable(True)
        self.action_fusion.setObjectName("action_fusion")
        self.action_windows = QtWidgets.QAction(main_entrance)
        self.action_windows.setCheckable(True)
        self.action_windows.setObjectName("action_windows")
        self.action_default = QtWidgets.QAction(main_entrance)
        self.action_default.setCheckable(True)
        self.action_default.setObjectName("action_default")
        self.menu_help.addAction(self.action_about)
        self.menu_style.addAction(self.action_default)
        self.menu_style.addAction(self.action_fusion)
        self.menu_style.addAction(self.action_windows)
        self.menu_settings.addAction(self.menu_style.menuAction())
        self.menubar.addAction(self.menu_settings.menuAction())
        self.menubar.addAction(self.menu_help.menuAction())

        self.retranslateUi(main_entrance)
        QtCore.QMetaObject.connectSlotsByName(main_entrance)

    def retranslateUi(self, main_entrance):
        _translate = QtCore.QCoreApplication.translate
        main_entrance.setWindowTitle(_translate("main_entrance", "AwesomePyKit"))
        self.pb_pkg_mgr.setToolTip(_translate("main_entrance", "管理不同 Python 环境中的第三方模块。"))
        self.pb_pkg_mgr.setText(_translate("main_entrance", "包管理器"))
        self.pb_pyi_tool.setToolTip(_translate("main_entrance", "使用 Pyinstaller 将 Python 程序打包成 exe 可执行文件。"))
        self.pb_pyi_tool.setText(_translate("main_entrance", "程序打包工具"))
        self.pb_index_mgr.setToolTip(_translate("main_entrance", "设置pip全局镜像源地址。"))
        self.pb_index_mgr.setText(_translate("main_entrance", "镜像源设置"))
        self.pb_pkg_dload.setToolTip(_translate("main_entrance", "Python 的模块、包下载工具，可批量下载。"))
        self.pb_pkg_dload.setText(_translate("main_entrance", "模块安装包下载"))
        self.menu_help.setTitle(_translate("main_entrance", "关于"))
        self.menu_settings.setTitle(_translate("main_entrance", "设置"))
        self.menu_style.setTitle(_translate("main_entrance", "界面风格"))
        self.description.setText(_translate("main_entrance", "功能说明"))
        self.action_about.setText(_translate("main_entrance", "关于软件"))
        self.contribution.setText(_translate("main_entrance", "参与贡献"))
        self.action_fusion.setText(_translate("main_entrance", "Fusion 风格"))
        self.action_windows.setText(_translate("main_entrance", "经典风格"))
        self.action_default.setText(_translate("main_entrance", "原生风格"))



# coding: utf-8

from enum import Enum, IntEnum


class Accept(Enum):
    """
    供一些需要接收区分'文件'或'目录'参数的函数、方法使用
    """

    File = "file"  # 接受文件
    Dir = "dir"  # 接受目录
    Both = "both"  # 全都接受


class AppStyle(IntEnum):
    Windows = 0  # XP 风格
    WindowsVista = 1  # 原生风格
    Fusion = 2  # Fusion 风格


class Linkage(IntEnum):
    """枚举：输出窗口的哪一侧吸附在主窗口上"""

    NoLink = 0  # 子窗口没有吸附在主窗口上
    Top = 1  # 子窗口顶部吸附在主窗口底部
    Left = 2  # 子窗口左侧吸附在主窗口右侧
    Right = 3  # 子窗口右侧吸附在主窗口左侧


class QMode(IntEnum):
    """包管理器的查询面板查询模式设置"""

    NotSPCF = 0  # 未指定查询方式
    Pkg2Imp = 1  # 以包名查导入名
    Imp2Pkg = 2  # 以导入名查包名
